# pickup-line
:wink: a cli tool to generate pickup-lines

[![MITlicensed](https://img.shields.io/badge/license-MIT-blue.svg)](https://raw.githubusercontent.com/prdpx7/pickup-line/master/LICENSE)
[![PyPI version](https://badge.fury.io/py/pickupline.svg)](https://badge.fury.io/py/pickupline)

## Installation
```
pip install pickupline
```
## Usage
```
$ pickup-line --help
usage: pickup-line [-h] [-g] [-d] [-m] [-s] [-p] [-r]

A CLI tool for generating PickupLine from web

optional arguments:
  -h, --help     show this help message and exit
  -g, --geek     get a geeky pickupline
  -d, --dirty    get a dirty pickupline
  -m, --math     get a math based pickupline
  -s, --scifi    get a scifi based pickupline
  -p, --physics  get a physics based pickupline
  -r, --random   get a random pickupline

the pickup-line will be copied to the clipboard
```
## Demo
<img src="https://i.imgur.com/QhSY9md.png" alt="snap">
